@@ -1,15 +1,12 @@
 """mlops is a package for conducting MLOps, including versioning of datasets and
 models."""
 
-__version__ = '0.0.14'
-
-import mlops.dataset
-import mlops.errors
-import mlops.model
+__version__ = '0.0.15'
 
 __all__ = [
     '__version__',
     'dataset',
     'errors',
-    'model'
+    'model',
+    'hashing'
 ]
